
XEP-0424: Message Retraction
============================

.. module:: slixmpp.plugins.xep_0424

.. autoclass:: XEP_0424
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0424.stanza
    :members:
    :undoc-members:

